@@ -365,173 +365,12 @@ def django_to_cache(
     )
 
 
-async def update_or_create_redis_instance_from_django_instance(
-        redis_root,
-        django_instance,
-        django_fields,
-        cache_conf,
-):
-
-    django_instance_model = django_instance.__class__
-    old_redis_instance = redis_root.get(django_instance_model, django_id=django_instance.id)
-    redis_dict = await django_instance_to_redis_params(
-        redis_root,
-        django_instance,
-        django_fields,
-        cache_conf,
-    )
-
-    if not old_redis_instance:
-        fields_to_create = redis_dict
-        redis_instance = redis_root.create(
-            django_model=django_instance_model,
-            django_id=django_instance.id,
-            **fields_to_create
-        )
-        result_redis_instance_id = redis_instance['id']
-    else:
-        old_redis_instance = old_redis_instance[0]
-        fields_to_update = check_fields_need_to_update(
-            old_redis_instance,
-            redis_dict,
-        )
-        if fields_to_update:
-            redis_root.update(django_instance_model, old_redis_instance,
-                              **fields_to_update
-                              )
-            redis_instance = redis_root.get(django_instance_model, django_id=django_instance.id)[0]
-            result_redis_instance_id = redis_instance['id']
-        else:
-            result_redis_instance_id = old_redis_instance['id']
 
 
-    return result_redis_instance_id
 
 
-def check_fields_need_to_update(
-        redis_instance,
-        redis_dict,
-):
-    fields_to_update = {}
-    for field_name, field_value in redis_dict.items():
-        if field_name not in redis_instance.keys():
-            fields_to_update[field_name] = field_value
-        else:
-            if redis_instance[field_name] != field_value:
-                fields_to_update[field_name] = field_value
-    return fields_to_update
 
 
-async def django_instance_field_to_redis_value(
-        redis_root,
-        django_instance,
-        django_field,
-        cache_conf,
-):
 
 
-    save_related_models = cache_conf['save_related_models']
-    django_field_value = await django_sync_to_async_get(django_instance, django_field.name)
-    redis_value = django_field_value
-    if django_field.__class__ == django_models.ForeignKey:
-        if django_field_value is None:
-            redis_value = None
-        else:
-            django_foreign_key_instance = django_field_value
-            if save_related_models:
-                if django_foreign_key_instance:
-                    django_instance_model = django_foreign_key_instance.__class__
-                    redis_foreign_key_instance = await get_or_create_redis_instance_from_django_instance(
-                        django_foreign_key_instance,
-                        redis_root,
-                        cache_conf,
-                    )
-                    redis_value = redis_foreign_key_instance
-                else:
-                    redis_value = None
-            else:
-                redis_value = django_foreign_key_instance.id
-    elif django_field.__class__ == django_models.ManyToManyField:
-        django_many_to_many_instances = await django_sync_to_async_list(django_field_value.all)
-        if save_related_models:
-            if len(django_many_to_many_instances):
-                django_instance_model = django_many_to_many_instances[0].__class__
-                redis_value = [
-                    await get_or_create_redis_instance_from_django_instance(
-                        django_many_to_many_instance,
-                        redis_root,
-                        cache_conf,
-                    )
-                    for django_many_to_many_instance in django_many_to_many_instances
-                ]
-            else:
-                redis_value = []
-        else:
-            redis_value = [
-                django_many_to_many_instance.id
-                for django_many_to_many_instance in django_many_to_many_instances
-            ]
-    elif django_field.__class__.__name__.startswith('Image') or django_field.__class__.__name__.startswith('File'):
-        try:
-            redis_value = django_field_value.file.path
-        except:
-            redis_value = None
-    return redis_value
 
-
-async def django_instance_to_redis_params(
-        redis_root,
-        django_instance,
-        django_fields,
-        cache_conf,
-):
-
-    redis_params = {}
-    exclude_fields = cache_conf['exclude_fields']
-
-    for i, django_field in enumerate(django_fields):
-        if not django_field.__class__.__name__.endswith('Rel'):
-            django_field_name = django_field.name
-            allowed = True
-            if exclude_fields:
-                allowed = (django_field.name not in exclude_fields)
-            if allowed:
-                if django_field.name not in ['id', 'pk']:
-                    redis_param = await django_instance_field_to_redis_value(
-                        redis_root,
-                        django_instance,
-                        django_field,
-                        cache_conf,
-                    )
-                    if redis_param:
-                        redis_params[django_field_name] = redis_param
-
-
-    return redis_params
-
-
-async def get_or_create_redis_instance_from_django_instance(
-        django_instance,
-        redis_root,
-        cache_conf,
-):
-    django_fields = django_instance.__class__._meta.get_fields()
-    django_instance_model = django_instance.__class__
-    redis_instance = redis_root.get(django_instance_model, django_id=django_instance.id)
-
-    if not redis_instance:
-        redis_dict = await django_instance_to_redis_params(
-            redis_root,
-            django_instance,
-            django_fields,
-            cache_conf,
-        )
-        redis_instance = redis_root.create(
-            django_model=django_instance_model,
-            django_id=django_instance.id,
-            **redis_dict
-        )
-    else:
-        redis_instance = redis_instance[0]
-
-    return redis_instance
