@@ -7,6 +7,9 @@ import redis
 from copy import deepcopy
 from typing import Callable
 from django.db import models as django_models
+from django.db.models.signals import post_save, pre_delete
+from django.dispatch import receiver
+
 from .utils import check_types, check_classes, get_ids_from_untyped_data
 from .cache import default_cache_func
 
@@ -722,6 +725,164 @@ class RedisRoot:
 
         return cache_conf
 
+    def update_or_create_redis_instance_from_django_instance(
+            self,
+            django_instance,
+            django_fields,
+            cache_conf,
+    ):
+        def check_fields_need_to_update(
+                redis_instance,
+                redis_dict,
+        ):
+            fields_to_update = {}
+            for field_name, field_value in redis_dict.items():
+                if field_name not in redis_instance.keys():
+                    fields_to_update[field_name] = field_value
+                else:
+                    if redis_instance[field_name] != field_value:
+                        fields_to_update[field_name] = field_value
+            return fields_to_update
+        
+        django_instance_model = django_instance.__class__
+        old_redis_instance = self.get(django_instance_model, django_id=django_instance.id)
+        redis_dict = self.django_instance_to_redis_params(
+            django_instance,
+            django_fields,
+            cache_conf,
+        )
+
+        if not old_redis_instance:
+            fields_to_create = redis_dict
+            redis_instance = self.create(
+                django_model=django_instance_model,
+                django_id=django_instance.id,
+                **fields_to_create
+            )
+            result_redis_instance_id = redis_instance['id']
+        else:
+            old_redis_instance = old_redis_instance[0]
+            fields_to_update = check_fields_need_to_update(
+                old_redis_instance,
+                redis_dict,
+            )
+            if fields_to_update:
+                self.update(django_instance_model, old_redis_instance,
+                                  **fields_to_update
+                                  )
+                redis_instance = self.get(django_instance_model, django_id=django_instance.id)[0]
+                result_redis_instance_id = redis_instance['id']
+            else:
+                result_redis_instance_id = old_redis_instance['id']
+
+        return result_redis_instance_id
+
+    def django_instance_to_redis_params(
+            self,
+            django_instance,
+            django_fields,
+            cache_conf,
+    ):
+
+        redis_params = {}
+        exclude_fields = cache_conf['exclude_fields']
+
+        for i, django_field in enumerate(django_fields):
+            if not django_field.__class__.__name__.endswith('Rel'):
+                django_field_name = django_field.name
+                allowed = True
+                if exclude_fields:
+                    allowed = (django_field.name not in exclude_fields)
+                if allowed:
+                    if django_field.name not in ['id', 'pk']:
+                        redis_param = self.django_instance_field_to_redis_value(
+                            django_instance,
+                            django_field,
+                            cache_conf,
+                        )
+                        if redis_param:
+                            redis_params[django_field_name] = redis_param
+
+        return redis_params
+
+    def django_instance_field_to_redis_value(
+            self,
+            django_instance,
+            django_field,
+            cache_conf,
+    ):
+
+        save_related_models = cache_conf['save_related_models']
+        django_field_value = getattr(django_instance, django_field.name, None)
+        redis_value = django_field_value
+        if django_field.__class__ == django_models.ForeignKey:
+            if django_field_value is None:
+                redis_value = None
+            else:
+                django_foreign_key_instance = django_field_value
+                if save_related_models:
+                    if django_foreign_key_instance:
+                        django_instance_model = django_foreign_key_instance.__class__
+                        redis_foreign_key_instance = self.get_or_create_redis_instance_from_django_instance(
+                            django_foreign_key_instance,
+                            cache_conf,
+                        )
+                        redis_value = redis_foreign_key_instance
+                    else:
+                        redis_value = None
+                else:
+                    redis_value = django_foreign_key_instance.id
+        elif django_field.__class__ == django_models.ManyToManyField:
+            django_many_to_many_instances = django_field_value.all()
+            if save_related_models:
+                if len(django_many_to_many_instances):
+                    django_instance_model = django_many_to_many_instances[0].__class__
+                    redis_value = [
+                        self.get_or_create_redis_instance_from_django_instance(
+                            django_many_to_many_instance,
+                            cache_conf,
+                        )
+                        for django_many_to_many_instance in django_many_to_many_instances
+                    ]
+                else:
+                    redis_value = []
+            else:
+                redis_value = [
+                    django_many_to_many_instance.id
+                    for django_many_to_many_instance in django_many_to_many_instances
+                ]
+        elif django_field.__class__.__name__.startswith('Image') or django_field.__class__.__name__.startswith('File'):
+            try:
+                redis_value = django_field_value.file.path
+            except:
+                redis_value = None
+        return redis_value
+
+    def get_or_create_redis_instance_from_django_instance(
+            self,
+            django_instance,
+            cache_conf,
+    ):
+        django_fields = django_instance.__class__._meta.get_fields()
+        django_instance_model = django_instance.__class__
+        redis_instance = self.get(django_instance_model, django_id=django_instance.id)
+
+        if not redis_instance:
+            redis_dict = self.django_instance_to_redis_params(
+                django_instance,
+                django_fields,
+                cache_conf,
+            )
+            redis_instance = self.create(
+                django_model=django_instance_model,
+                django_id=django_instance.id,
+                **redis_dict
+            )
+        else:
+            redis_instance = redis_instance[0]
+
+        return redis_instance
+
     def register_django_models(self, models_dict):
         for model, user_cache_conf in models_dict.items():
             if issubclass(model, django_models.Model):
@@ -731,6 +892,24 @@ class RedisRoot:
                         'cache_conf': cache_conf,
                         'to_cache_in': datetime.datetime.now()
                     }
+
+                    @receiver(post_save, sender=model)
+                    def save_redis_instance_from_django_instance(sender, instance, **kwargs):
+                        django_fields = sender._meta.get_fields()
+                        self.update_or_create_redis_instance_from_django_instance(
+                            instance,
+                            django_fields,
+                            cache_conf
+                        )
+                        print('Called save_redis_instance_from_django_instance')
+
+                    @receiver(pre_delete, sender=model)
+                    def delete_redis_instance_from_django_instance(sender, instance, **kwargs):
+                        redis_instances_qs = self.get(sender, django_id=instance.id)
+                        if redis_instances_qs:
+                            self.delete(sender, redis_instances_qs)
+                        print('Called delete_redis_instance_from_django_instance')
+
             else:
                 raise Exception(f'{model.__name__} class is not django_models.Model')
 
